package containeranalysispb
import "cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb"
Index ¶
- Variables
- func RegisterContainerAnalysisV1Beta1Server(s *grpc.Server, srv ContainerAnalysisV1Beta1Server)
- type ContainerAnalysisV1Beta1Client
- type ContainerAnalysisV1Beta1Server
- type ExportSBOMRequest
- func (*ExportSBOMRequest) Descriptor() ([]byte, []int)
- func (x *ExportSBOMRequest) GetName() string
- func (*ExportSBOMRequest) ProtoMessage()
- func (x *ExportSBOMRequest) ProtoReflect() protoreflect.Message
- func (x *ExportSBOMRequest) Reset()
- func (x *ExportSBOMRequest) String() string
- type ExportSBOMResponse
- func (*ExportSBOMResponse) Descriptor() ([]byte, []int)
- func (x *ExportSBOMResponse) GetDiscoveryOccurrenceId() string
- func (*ExportSBOMResponse) ProtoMessage()
- func (x *ExportSBOMResponse) ProtoReflect() protoreflect.Message
- func (x *ExportSBOMResponse) Reset()
- func (x *ExportSBOMResponse) String() string
- type GeneratePackagesSummaryRequest
- func (*GeneratePackagesSummaryRequest) Descriptor() ([]byte, []int)
- func (x *GeneratePackagesSummaryRequest) GetName() string
- func (*GeneratePackagesSummaryRequest) ProtoMessage()
- func (x *GeneratePackagesSummaryRequest) ProtoReflect() protoreflect.Message
- func (x *GeneratePackagesSummaryRequest) Reset()
- func (x *GeneratePackagesSummaryRequest) String() string
- type PackagesSummaryResponse
- func (*PackagesSummaryResponse) Descriptor() ([]byte, []int)
- func (x *PackagesSummaryResponse) GetLicensesSummary() []*PackagesSummaryResponse_LicensesSummary
- func (x *PackagesSummaryResponse) GetResourceUrl() string
- func (*PackagesSummaryResponse) ProtoMessage()
- func (x *PackagesSummaryResponse) ProtoReflect() protoreflect.Message
- func (x *PackagesSummaryResponse) Reset()
- func (x *PackagesSummaryResponse) String() string
- type PackagesSummaryResponse_LicensesSummary
- func (*PackagesSummaryResponse_LicensesSummary) Descriptor() ([]byte, []int)
- func (x *PackagesSummaryResponse_LicensesSummary) GetCount() int64
- func (x *PackagesSummaryResponse_LicensesSummary) GetLicense() string
- func (*PackagesSummaryResponse_LicensesSummary) ProtoMessage()
- func (x *PackagesSummaryResponse_LicensesSummary) ProtoReflect() protoreflect.Message
- func (x *PackagesSummaryResponse_LicensesSummary) Reset()
- func (x *PackagesSummaryResponse_LicensesSummary) String() string
- type UnimplementedContainerAnalysisV1Beta1Server
- func (*UnimplementedContainerAnalysisV1Beta1Server) ExportSBOM(context.Context, *ExportSBOMRequest) (*ExportSBOMResponse, error)
- func (*UnimplementedContainerAnalysisV1Beta1Server) GeneratePackagesSummary(context.Context, *GeneratePackagesSummaryRequest) (*PackagesSummaryResponse, error)
- func (*UnimplementedContainerAnalysisV1Beta1Server) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
- func (*UnimplementedContainerAnalysisV1Beta1Server) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
- func (*UnimplementedContainerAnalysisV1Beta1Server) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
Variables ¶
var File_google_devtools_containeranalysis_v1beta1_containeranalysis_proto protoreflect.FileDescriptor
Functions ¶
func RegisterContainerAnalysisV1Beta1Server ¶
func RegisterContainerAnalysisV1Beta1Server(s *grpc.Server, srv ContainerAnalysisV1Beta1Server)
Types ¶
type ContainerAnalysisV1Beta1Client ¶
type ContainerAnalysisV1Beta1Client interface {
// Sets the access control policy on the specified note or occurrence.
// Requires `containeranalysis.notes.setIamPolicy` or
// `containeranalysis.occurrences.setIamPolicy` permission if the resource is
// a note or an occurrence, respectively.
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
SetIamPolicy(ctx context.Context, in *iampb.SetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Gets the access control policy for a note or an occurrence resource.
// Requires `containeranalysis.notes.setIamPolicy` or
// `containeranalysis.occurrences.setIamPolicy` permission if the resource is
// a note or occurrence, respectively.
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
GetIamPolicy(ctx context.Context, in *iampb.GetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Returns the permissions that a caller has on the specified note or
// occurrence. Requires list permission on the project (for example,
// `containeranalysis.notes.list`).
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
TestIamPermissions(ctx context.Context, in *iampb.TestIamPermissionsRequest, opts ...grpc.CallOption) (*iampb.TestIamPermissionsResponse, error)
// Gets a summary of the packages within a given resource.
GeneratePackagesSummary(ctx context.Context, in *GeneratePackagesSummaryRequest, opts ...grpc.CallOption) (*PackagesSummaryResponse, error)
// Generates an SBOM and other dependency information for the given resource.
ExportSBOM(ctx context.Context, in *ExportSBOMRequest, opts ...grpc.CallOption) (*ExportSBOMResponse, error)
}
ContainerAnalysisV1Beta1Client is the client API for ContainerAnalysisV1Beta1 service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewContainerAnalysisV1Beta1Client ¶
func NewContainerAnalysisV1Beta1Client(cc grpc.ClientConnInterface) ContainerAnalysisV1Beta1Client
type ContainerAnalysisV1Beta1Server ¶
type ContainerAnalysisV1Beta1Server interface {
// Sets the access control policy on the specified note or occurrence.
// Requires `containeranalysis.notes.setIamPolicy` or
// `containeranalysis.occurrences.setIamPolicy` permission if the resource is
// a note or an occurrence, respectively.
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
// Gets the access control policy for a note or an occurrence resource.
// Requires `containeranalysis.notes.setIamPolicy` or
// `containeranalysis.occurrences.setIamPolicy` permission if the resource is
// a note or occurrence, respectively.
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
// Returns the permissions that a caller has on the specified note or
// occurrence. Requires list permission on the project (for example,
// `containeranalysis.notes.list`).
//
// The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for
// notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for
// occurrences.
TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
// Gets a summary of the packages within a given resource.
GeneratePackagesSummary(context.Context, *GeneratePackagesSummaryRequest) (*PackagesSummaryResponse, error)
// Generates an SBOM and other dependency information for the given resource.
ExportSBOM(context.Context, *ExportSBOMRequest) (*ExportSBOMResponse, error)
}
ContainerAnalysisV1Beta1Server is the server API for ContainerAnalysisV1Beta1 service.
type ExportSBOMRequest ¶
type ExportSBOMRequest struct {
// Required. The name of the resource in the form of
// `projects/[PROJECT_ID]/resources/[RESOURCE_URL]`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request to a call of ExportSBOM
func (*ExportSBOMRequest) Descriptor ¶
func (*ExportSBOMRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExportSBOMRequest.ProtoReflect.Descriptor instead.
func (*ExportSBOMRequest) GetName ¶
func (x *ExportSBOMRequest) GetName() string
func (*ExportSBOMRequest) ProtoMessage ¶
func (*ExportSBOMRequest) ProtoMessage()
func (*ExportSBOMRequest) ProtoReflect ¶
func (x *ExportSBOMRequest) ProtoReflect() protoreflect.Message
func (*ExportSBOMRequest) Reset ¶
func (x *ExportSBOMRequest) Reset()
func (*ExportSBOMRequest) String ¶
func (x *ExportSBOMRequest) String() string
type ExportSBOMResponse ¶
type ExportSBOMResponse struct {
// The name of the discovery occurrence in the form
// "projects/{project_id}/occurrences/{OCCURRENCE_ID}
// It can be used to track the progression of the SBOM export.
DiscoveryOccurrenceId string `protobuf:"bytes,1,opt,name=discovery_occurrence_id,json=discoveryOccurrenceId,proto3" json:"discovery_occurrence_id,omitempty"`
// contains filtered or unexported fields
}
The response from a call to ExportSBOM
func (*ExportSBOMResponse) Descriptor ¶
func (*ExportSBOMResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExportSBOMResponse.ProtoReflect.Descriptor instead.
func (*ExportSBOMResponse) GetDiscoveryOccurrenceId ¶
func (x *ExportSBOMResponse) GetDiscoveryOccurrenceId() string
func (*ExportSBOMResponse) ProtoMessage ¶
func (*ExportSBOMResponse) ProtoMessage()
func (*ExportSBOMResponse) ProtoReflect ¶
func (x *ExportSBOMResponse) ProtoReflect() protoreflect.Message
func (*ExportSBOMResponse) Reset ¶
func (x *ExportSBOMResponse) Reset()
func (*ExportSBOMResponse) String ¶
func (x *ExportSBOMResponse) String() string
type GeneratePackagesSummaryRequest ¶
type GeneratePackagesSummaryRequest struct {
// Required. The name of the resource to get a packages summary for in the
// form of `projects/[PROJECT_ID]/resources/[RESOURCE_URL]`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
GeneratePackagesSummaryRequest is the request body for the GeneratePackagesSummary API method. It just takes a single name argument, referring to the resource.
func (*GeneratePackagesSummaryRequest) Descriptor ¶
func (*GeneratePackagesSummaryRequest) Descriptor() ([]byte, []int)
Deprecated: Use GeneratePackagesSummaryRequest.ProtoReflect.Descriptor instead.
func (*GeneratePackagesSummaryRequest) GetName ¶
func (x *GeneratePackagesSummaryRequest) GetName() string
func (*GeneratePackagesSummaryRequest) ProtoMessage ¶
func (*GeneratePackagesSummaryRequest) ProtoMessage()
func (*GeneratePackagesSummaryRequest) ProtoReflect ¶
func (x *GeneratePackagesSummaryRequest) ProtoReflect() protoreflect.Message
func (*GeneratePackagesSummaryRequest) Reset ¶
func (x *GeneratePackagesSummaryRequest) Reset()
func (*GeneratePackagesSummaryRequest) String ¶
func (x *GeneratePackagesSummaryRequest) String() string
type PackagesSummaryResponse ¶
type PackagesSummaryResponse struct {
// The unique URL of the image or the container for which this summary
// applies.
ResourceUrl string `protobuf:"bytes,1,opt,name=resource_url,json=resourceUrl,proto3" json:"resource_url,omitempty"`
// A listing by license name of each of the licenses and their counts.
LicensesSummary []*PackagesSummaryResponse_LicensesSummary `protobuf:"bytes,2,rep,name=licenses_summary,json=licensesSummary,proto3" json:"licenses_summary,omitempty"`
// contains filtered or unexported fields
}
A summary of the packages found within the given resource.
func (*PackagesSummaryResponse) Descriptor ¶
func (*PackagesSummaryResponse) Descriptor() ([]byte, []int)
Deprecated: Use PackagesSummaryResponse.ProtoReflect.Descriptor instead.
func (*PackagesSummaryResponse) GetLicensesSummary ¶
func (x *PackagesSummaryResponse) GetLicensesSummary() []*PackagesSummaryResponse_LicensesSummary
func (*PackagesSummaryResponse) GetResourceUrl ¶
func (x *PackagesSummaryResponse) GetResourceUrl() string
func (*PackagesSummaryResponse) ProtoMessage ¶
func (*PackagesSummaryResponse) ProtoMessage()
func (*PackagesSummaryResponse) ProtoReflect ¶
func (x *PackagesSummaryResponse) ProtoReflect() protoreflect.Message
func (*PackagesSummaryResponse) Reset ¶
func (x *PackagesSummaryResponse) Reset()
func (*PackagesSummaryResponse) String ¶
func (x *PackagesSummaryResponse) String() string
type PackagesSummaryResponse_LicensesSummary ¶
type PackagesSummaryResponse_LicensesSummary struct {
// The license of the package. Note that the format of this value is not
// guaranteed. It may be nil, an empty string, a boolean value (A | B), a
// differently formed boolean value (A OR B), etc...
License string `protobuf:"bytes,1,opt,name=license,proto3" json:"license,omitempty"`
// The number of fixable vulnerabilities associated with this resource.
Count int64 `protobuf:"varint,2,opt,name=count,proto3" json:"count,omitempty"`
// contains filtered or unexported fields
}
Per license count
func (*PackagesSummaryResponse_LicensesSummary) Descriptor ¶
func (*PackagesSummaryResponse_LicensesSummary) Descriptor() ([]byte, []int)
Deprecated: Use PackagesSummaryResponse_LicensesSummary.ProtoReflect.Descriptor instead.
func (*PackagesSummaryResponse_LicensesSummary) GetCount ¶
func (x *PackagesSummaryResponse_LicensesSummary) GetCount() int64
func (*PackagesSummaryResponse_LicensesSummary) GetLicense ¶
func (x *PackagesSummaryResponse_LicensesSummary) GetLicense() string
func (*PackagesSummaryResponse_LicensesSummary) ProtoMessage ¶
func (*PackagesSummaryResponse_LicensesSummary) ProtoMessage()
func (*PackagesSummaryResponse_LicensesSummary) ProtoReflect ¶
func (x *PackagesSummaryResponse_LicensesSummary) ProtoReflect() protoreflect.Message
func (*PackagesSummaryResponse_LicensesSummary) Reset ¶
func (x *PackagesSummaryResponse_LicensesSummary) Reset()
func (*PackagesSummaryResponse_LicensesSummary) String ¶
func (x *PackagesSummaryResponse_LicensesSummary) String() string
type UnimplementedContainerAnalysisV1Beta1Server ¶
type UnimplementedContainerAnalysisV1Beta1Server struct {
}
UnimplementedContainerAnalysisV1Beta1Server can be embedded to have forward compatible implementations.
func (*UnimplementedContainerAnalysisV1Beta1Server) ExportSBOM ¶
func (*UnimplementedContainerAnalysisV1Beta1Server) ExportSBOM(context.Context, *ExportSBOMRequest) (*ExportSBOMResponse, error)
func (*UnimplementedContainerAnalysisV1Beta1Server) GeneratePackagesSummary ¶
func (*UnimplementedContainerAnalysisV1Beta1Server) GeneratePackagesSummary(context.Context, *GeneratePackagesSummaryRequest) (*PackagesSummaryResponse, error)
func (*UnimplementedContainerAnalysisV1Beta1Server) GetIamPolicy ¶
func (*UnimplementedContainerAnalysisV1Beta1Server) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
func (*UnimplementedContainerAnalysisV1Beta1Server) SetIamPolicy ¶
func (*UnimplementedContainerAnalysisV1Beta1Server) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
func (*UnimplementedContainerAnalysisV1Beta1Server) TestIamPermissions ¶
func (*UnimplementedContainerAnalysisV1Beta1Server) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
Source Files ¶
containeranalysis.pb.go
- Version
- v0.14.1 (latest)
- Published
- Apr 15, 2025
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 10 months ago –
Tools for package owners.